---
title: Contributing to the Wiki
layout: article
navigation: 
---

# Contributing to the Wiki

## 1/ Create an account

The wiki is based on gitlab pages, and we are using the gitlab's instance of the Pasteur Institute. To contribute, users need to be part of the project.

On every page, there is a button at the bottom proposing to "Edit on Gitlab". It will allow anyone registered to edit a given page seamlessly.
But on the first try, the following dialog will be prompted. If you have a Pasteur account, chose 1, otherwise chose 2. In External account, you can connect with a third-party account such as Github, bitbucket or google.
If you have neither, register on Github first (it's always useful).

![Register](/help/register_1.png){max-width=750px}

Once your account is created, you need to request access to the project, on the [gitlab page of the wiki](https://gitlab.pasteur.fr/mdm-lab/wiki) of the repo, there is a small link to request access.

![Request Access](/help/Request_access.png){max-width=600px}

Click, and wait for an admin approval.

## 2/ Edit a page

Once you have access to the project (the previous step is done once), you can edit easily each page of the wiki, and post [issues](https://gitlab.pasteur.fr/mdm-lab/wiki/-/issues) (if you have question about something or remarks with anything from content to design).

To edit a page, just click on the Edit on Gitlab button at the bottom of every page of the wiki, and it will lead you to the corresponding page of the wiki.

From this page, you can :

1. Edit the text you'd like
2. Preview the change you've done (final modification might a bit different, especially if you use plugins to view citations or pdb structures)
3. Once you've finished you edits, you can specify what you did (e.g. "Re-wrote history of defense systems")
4. This field is for the branch name, you can let it with the default value, or specify a more meaningful name (note that it's good to have your user name in the branch name so we can)

![Edit a page](/help/Edit_page.png){max-width=750px}

Then it asks you to create a merge request.
In other words, the modifications you made will not be reflected on the website until a few automatic checks passed (which should be ok since you modified only some text) and that another person reviewed the change, and accept the merge request.

To do so, just fill in the description (1) of what you did, or anything that you would like the person who will accept the merge request to know, and just hit (2) "Create a merge request".

![Create MR](/help/Create_MR.png){max-width=750px}

## 3/ Tips to write Markdown

As a general advice, check an already written file to see how other pages are written.<br><br>

The files you edit are in markdown, which is pretty basic language but that can let you do many things, such as tables, links and such with a particular syntax.
You can check more about this syntax here : <https://docs.gitlab.com/ee/user/markdown.html><br><br>

To add images, you need to upload the image in the `/content/public` folder (and possibly in the corresponding folder of the defense system)
and you can specify its path in the markdown file as follows :<br>  

```md
![Alt-text, get printed if image is not found](/path/within/public)
```  

where `/path/within/public` is the relative path to the `public` folder (the absolute path would be `/content/public/path/within/public`)<br>

In addition to this, there are some specificities to this wiki :<br><br>

**1. Each system's page has *frontmatter*, which is a piece of code that will be used to populate the table of the list of system. It has the following syntax :**

```yaml
---
title: Viperin
tableColumns:
    article:
    doi: 10.1038/s41586-020-2762-2
    abstract: |
        <the abstract>
    Sensor: Unknown
    Activator: Direct
    Effector: Nucleotide modifying
    PFAM: PF04055, PF13353
RelevantAbstracts:
    - doi: 10.1038/s41586-020-2762-2
    - doi: 10.1126/science.aba0372    
contributors : 
    - Florian Tesson
    - Aude Bernheim
---
```

Any new item in the `tableColumns` object will create a new column in the list of [defense system's table](/defense-systems).<br>

**2. To display a protein structure, you can call the plugin as follows :**

```
::molstar-pdbe-plugin
---
height: 700
dataUrls: 
    - /avs/AVAST_I,AVAST_I__Avs1B,0,V-plddts_80.96481.pdb
---
::
```

**Custom containers:**

Custom containers can be defined by their types, titles, and contents.

<u>Default title:</u>

```md
::info
This is an info box
::
```

```md
::tip
This is a tip box
::
```

```md
::warning
This is a warning box
::
```

```md
::danger
This is a danger box
::
```

```md
::expansion-details
There is some details
::
```

<u>The output:</u>

::info
This is an info box
::

::tip
This is a tip box
::

::warning
This is a warning box
::

::danger
This is a danger box
::

::expansion-details
There is some details
::

<u>Custom title:</u>

```md
::info
---
title: my title info
---
This is an info box
::
```

::info
---
title: my title info
---
This is an info box
::

### 4/ Review a Merge Request

You can review other person's merge request by going the [merge request's pages](https://gitlab.pasteur.fr/mdm-lab/wiki/-/merge_requests).

On a given page, you can see what modifications where made for this merge request (1), then you can comment if you have anything to say (2 and 3).
And finally, you can approve (4) the MR if you find it worth publishing on the website.

![review a MR](/help/Review_MR.png){max-width=750px}

If you want to modify further the file or other file within the same merge request, go to "Changes (1)", and then click on the 3 little dots (see arrow on image) and then "Edit in single-file editor", or "Open in Web IDE".

![Edit_MR](/help/Edit_MR.png){max-width=750px}

The Web IDE editor allows you to edit multiple file at once for a given commit. This editor is also accessible from the merge request's page under the "Code" button in the upper right corner of the page.

## Contribute to the code

Contribution to the code and design are open. Please read the [README](https://gitlab.pasteur.fr/mdm-lab/wiki) on how to deploy the website locally (and see the modification you're doing live).
